<!DOCTYPE TS><TS>
<defaultcodec></defaultcodec>
<context>
    <name>AdvSearch</name>
    <message>
        <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
        <translation>Невозможно выполнить полностью негативный запрос. Пожалуйста, введите общие термины в поле &quot;любые слова&quot;</translation>
    </message>
    <message>
        <source>All clauses</source>
        <translation>Все поля</translation>
    </message>
    <message>
        <source>Any clause</source>
        <translation>Любое поле</translation>
    </message>
    <message>
        <source>Cannot execute pure negativequery. Please enter common terms in the &apos;any words&apos; field</source>
        <translation type="obsolete">Невозможно выполнить полностью негативный запрос. Пожалуйста, введите общие термины в поле &quot;любые слова&quot;</translation>
    </message>
    <message>
        <source>texts</source>
        <translation>тексты</translation>
    </message>
    <message>
        <source>spreadsheets</source>
        <translation>таблицы</translation>
    </message>
    <message>
        <source>presentations</source>
        <translation>презентации</translation>
    </message>
    <message>
        <source>media</source>
        <translation>мультимедиа</translation>
    </message>
    <message>
        <source>messages</source>
        <translation>сообщения</translation>
    </message>
    <message>
        <source>other</source>
        <translation>иное</translation>
    </message>
</context>
<context>
    <name>AdvSearchBase</name>
    <message>
        <source>Advanced search</source>
        <translation>Сложный поиск</translation>
    </message>
    <message>
        <source>Search for files&lt;br&gt;having all of:</source>
        <translation type="obsolete">Искать&lt;br&gt;файлы:</translation>
    </message>
    <message>
        <source>All non blank fields will be combined with AND conjunctions. &lt;br&gt;All fields except &quot;exact phrase&quot; can accept a mix of simple words, and phrases enclosed in double quotes.</source>
        <translation type="obsolete">Все непустые поля объединяются логическим &quot;И&quot;.&lt;br&gt;Все поля кроме &quot;точная фраза&quot; принимают набор простых слов и фразы в двойных кавычках.</translation>
    </message>
    <message>
        <source>All of these</source>
        <translation type="obsolete">со всеми словами</translation>
    </message>
    <message>
        <source>Enter words, and/or quoted phrases.</source>
        <translation type="obsolete">Введите слова и/или фразы в кавычках.</translation>
    </message>
    <message>
        <source>This exact phrase</source>
        <translation type="obsolete">с точной фразой</translation>
    </message>
    <message>
        <source>Enter words.</source>
        <translation type="obsolete">Введите слова.</translation>
    </message>
    <message>
        <source>Any of these</source>
        <translation type="obsolete">с любыми словами</translation>
    </message>
    <message>
        <source>None of these</source>
        <translation type="obsolete">без этих слов</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation type="obsolete">с именем</translation>
    </message>
    <message>
        <source>Enter file name. * and ? are wildcards.</source>
        <translation type="obsolete">Введите имя файла. * и ? являются шаблонами.</translation>
    </message>
    <message>
        <source>Restrict file types</source>
        <translation>Ограничить типы файлов</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Сохранить как умолчание</translation>
    </message>
    <message>
        <source>Searched file types</source>
        <translation>Искомые</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation>Все ----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation>Эти ----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation>&lt;----- Эти</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation>&lt;----- Все</translation>
    </message>
    <message>
        <source>Ignored file types</source>
        <translation>Игнорируемые</translation>
    </message>
    <message>
        <source>Enter top directory for search</source>
        <translation>Введите каталог начала поиска</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Restrict results to files in subtree:</source>
        <translation>Искать только в каталоге:</translation>
    </message>
    <message>
        <source>Start Search</source>
        <translation>Начать поиск</translation>
    </message>
    <message>
        <source>Dismiss</source>
        <translation type="obsolete">Отменить</translation>
    </message>
    <message>
        <source>Search for &lt;br&gt;documents&lt;br&gt;satisfying:</source>
        <translation>Искать &lt;br&gt;документы,&lt;br&gt;удовлетворяющие:</translation>
    </message>
    <message>
        <source>All non blank fields will be combined with OR or AND conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
        <translation type="obsolete">Все непустые поля будут объединены при помощи ИЛИ или И. &lt;br&gt;Поля &quot;с любыми&quot;, &quot;со всеми&quot; и &quot;без этих&quot; работают со словами и фразами в двойных кавычках.&lt;br&gt;Пустые поля не принимаются в расчёт.</translation>
    </message>
    <message>
        <source>Delete clause</source>
        <translation>Убрать поле</translation>
    </message>
    <message>
        <source>Add clause</source>
        <translation>Добавить поле</translation>
    </message>
    <message>
        <source>Check this to enable filtering on file types</source>
        <translation>Фильтровать по типам файлов</translation>
    </message>
    <message>
        <source>By categories</source>
        <translation>По категориям</translation>
    </message>
    <message>
        <source>Check this to use file categories instead of raw mime types</source>
        <translation>Использовать категории, а не типы MIME</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>All non empty fields on the right will be combined with AND (&quot;All clauses&quot; choice) or OR (&quot;Any clause&quot; choice) conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
        <translation>Все непустые поля справа будут объединены логическим И (&quot;все слова&quot;) или ИЛИ (&quot;любое слово&quot;). &lt;br&gt;Поля типа &quot;любые&quot;, &quot;все&quot; или &quot;без этих&quot; принимают набор простых слов и фразы, заключённые в двойные кавычки.&lt;br&gt;Пустые поля игнорируются.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Configuration problem: </source>
        <translation type="obsolete">Проблема конфигурации: </translation>
    </message>
    <message>
        <source>No db directory in configuration</source>
        <translation>Нет каталога БД в конфигурации</translation>
    </message>
    <message>
        <source>Cannot create temporary directory</source>
        <translation type="obsolete">Невозможно создать временный каталог</translation>
    </message>
    <message>
        <source>Could not open database in </source>
        <translation>Невозможно открыть БД в </translation>
    </message>
    <message>
        <source>.
Click Cancel if you want to edit the configuration file before indexation starts, or Ok to let it proceed.</source>
        <translation>.
Нажмите &quot;Отменить&quot;, если хотите исправить файл конфигурации до начала индексирования, или &quot;OK&quot; для продолжения.</translation>
    </message>
    <message>
        <source>Configuration problem (dynconf</source>
        <translation>Проблема конфигурации (dynconf</translation>
    </message>
</context>
<context>
    <name>Preview</name>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Предв. просмотр</translation>
    </message>
    <message>
        <source>Preview 1</source>
        <translation type="obsolete">Предв. просмотр 1</translation>
    </message>
    <message>
        <source>&amp;Search for:</source>
        <translation>&amp;Искать:</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Дальше</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Предыдущее</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation type="obsolete">Alt+P</translation>
    </message>
    <message>
        <source>Match &amp;Case</source>
        <translation>&amp;Соблюдать регистр</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Can&apos;t turn doc into internal rep for </source>
        <translation type="obsolete">Невозможно создать внутреннее представление </translation>
    </message>
    <message>
        <source>Creating preview text</source>
        <translation>Создаю текст для просмотра</translation>
    </message>
    <message>
        <source>Loading preview text into editor</source>
        <translation>Загружаю текст в редактор</translation>
    </message>
    <message>
        <source>Cannot create temporary directory</source>
        <translation>Невозможно создать временный каталог</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation>Закрыть вкладку</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="obsolete">Файл не существует</translation>
    </message>
    <message>
        <source>Missing helper program: </source>
        <translation>Отсутствует вспомогательная программа: </translation>
    </message>
    <message>
        <source>Can&apos;t turn doc into internal representation for </source>
        <translation>Невозможно сконвертировать документ во внутреннее представление </translation>
    </message>
</context>
<context>
    <name>PreviewBase</name>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Предв. просмотр</translation>
    </message>
    <message>
        <source>Preview 1</source>
        <translation type="obsolete">Предв. просмотр 1</translation>
    </message>
    <message>
        <source>&amp;Search for:</source>
        <translation type="obsolete">&amp;Искать:</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="obsolete">&amp;Дальше</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="obsolete">&amp;Предыдущее</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation type="obsolete">Alt+P</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Очистить</translation>
    </message>
    <message>
        <source>Match &amp;Case</source>
        <translation type="obsolete">&amp;Соблюдать регистр</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
</context>
<context>
    <name>PreviewTextEdit</name>
    <message>
        <source>Show fields</source>
        <translation>Показать поля</translation>
    </message>
    <message>
        <source>Show main text</source>
        <translation>Показать основной текст</translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print Current Preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Global parameters</source>
        <translation>Общие параметры</translation>
    </message>
    <message>
        <source>Local parameters</source>
        <translation>Частные параметры</translation>
    </message>
    <message>
        <source>&lt;b&gt;Customised subtrees</source>
        <translation>&lt;b&gt;Каталоги с особенностями</translation>
    </message>
    <message>
        <source>The list of subdirectories in the indexed hierarchy &lt;br&gt;where some parameters need to be redefined. Default: empty.</source>
        <translation>Список подкаталогов в индексируемой иерархии,&lt;br&gt;где некоторые параметры нуждаются в коррекции.  Обычно пуст.</translation>
    </message>
    <message>
        <source>&lt;i&gt;The parameters that follow are set either at the top level, if nothing&lt;br&gt;or an empty line is selected in the listbox above, or for the selected subdirectory.&lt;br&gt;You can add or remove directories by clicking the +/- buttons.</source>
        <translation>&lt;i&gt;Следующие параметры устанавливаются на верхнем уровне, если выбрать&lt;br&gt;ничего или пустую строку, или для выбранного подкаталога.&lt;br&gt;Вы можете добавлять и удалять каталоги кнопками +/-.</translation>
    </message>
    <message>
        <source>Skipped names</source>
        <translation>Пропускаемые имена</translation>
    </message>
    <message>
        <source>These are patterns for file or directory  names which should not be indexed.</source>
        <translation>Шаблоны имён файлов или каталогов, которые не следует индексировать.</translation>
    </message>
    <message>
        <source>Default character set</source>
        <translation>Кодировка по умолчанию</translation>
    </message>
    <message>
        <source>This is the character set used for reading files which do not identify the character set internally, for example pure text files.&lt;br&gt;The default value is empty, and the value from the NLS environnement is used.</source>
        <translation>Эта кодировка будет использована при чтении файлов, в которых таковая не указывается явно (например, чисто текстовых файлов).&lt;br&gt;Обычно значение пусто, тогда оно извлекается из окружения (локали).</translation>
    </message>
    <message>
        <source>Follow symbolic links</source>
        <translation>Раскрывать символические ссылки</translation>
    </message>
    <message>
        <source>Follow symbolic links while indexing. The default is no, to avoid duplicate indexing</source>
        <translation>Ходить по символическим ссылкам при индексировании.  Обычно не делается для избежания дублей</translation>
    </message>
    <message>
        <source>Index all file names</source>
        <translation>Индексировать все имена файлов</translation>
    </message>
    <message>
        <source>Index the names of files for which the contents cannot be identified or processed (no or unsupported mime type). Default true</source>
        <translation>Индексировать и те имена файлов, для которых не получается определить или обработать содержимое (неизвестный или неподдерживаемый тип MIME).  Обычно так</translation>
    </message>
    <message>
        <source>Beagle web history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGuiResListPager</name>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;Не найдено&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="obsolete">Предыдущая</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="obsolete">Следующая</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="obsolete">Документ недоступен</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Предв. просмотр</translation>
    </message>
    <message>
        <source>(show query)</source>
        <translation type="obsolete">(показать запрос)</translation>
    </message>
</context>
<context>
    <name>RclMain</name>
    <message>
        <source>Indexing in progress</source>
        <translation type="obsolete">Идёт индексирование</translation>
    </message>
    <message>
        <source>Query results</source>
        <translation>Результаты поиска</translation>
    </message>
    <message>
        <source>Query results (sorted)</source>
        <translation type="obsolete">Результаты поиска (сортированные)</translation>
    </message>
    <message>
        <source>Advanced search</source>
        <translation type="obsolete">Сложный поиск</translation>
    </message>
    <message>
        <source>Sort criteria</source>
        <translation type="obsolete">Критерии сортировки</translation>
    </message>
    <message>
        <source>User interface preferences</source>
        <translation type="obsolete">Предпочтения интерфейса</translation>
    </message>
    <message>
        <source>Cannot retrieve document info from database</source>
        <translation>Невозможно извлечь информацию документа из БД</translation>
    </message>
    <message>
        <source>Cannot access document file: </source>
        <translation type="obsolete">Невозможно открыть документ: </translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Предв. просмотр</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Осторожно</translation>
    </message>
    <message>
        <source>Can&apos;t create preview window</source>
        <translation>Невозможно создать окно предпросмотра</translation>
    </message>
    <message>
        <source>No external viewer configured for mime type </source>
        <translation type="obsolete">Неизвестна программа просмотра для </translation>
    </message>
    <message>
        <source>Executing: [</source>
        <translation>Выполняю: [</translation>
    </message>
    <message>
        <source>About Recoll</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Starting help browser </source>
        <translation type="obsolete">Запускаю просмотр справки </translation>
    </message>
    <message>
        <source>Document history</source>
        <translation>История документов</translation>
    </message>
    <message>
        <source>Document history (sorted)</source>
        <translation type="obsolete">История документов (сортированная)</translation>
    </message>
    <message>
        <source>History data</source>
        <translation>Данные истории</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation type="obsolete">Детали запроса</translation>
    </message>
    <message>
        <source>Indexing in progress: </source>
        <translation>Индексирование: </translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Файлы</translation>
    </message>
    <message>
        <source>Purge</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Stemdb</source>
        <translation>База корней</translation>
    </message>
    <message>
        <source>Closing</source>
        <translation>Закрываю</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Неизвестно</translation>
    </message>
    <message>
        <source>This search is not active any more</source>
        <translation>Этот поиск уже не активен</translation>
    </message>
    <message>
        <source>Cant start query: </source>
        <translation type="obsolete">Невозможно начать запрос: </translation>
    </message>
    <message>
        <source>Bad viewer command line for %1: [%2]
Please check the mimeconf file</source>
        <translation>Неверная командная строка программы просмотра %1: [%2]
Проверьте файл mimeconf</translation>
    </message>
    <message>
        <source>The viewer specified in mimeconf for %1: %2 is not found.
Do you want to start the  preferences dialog ?</source>
        <translation type="obsolete">Программа просмотра, указанная в mimeconf для %1: %2, не найдена.
Открыть диалог настроек?</translation>
    </message>
    <message>
        <source>Cannot extract document or create temporary file</source>
        <translation>Невозможно извлечь документ или создать временный файл</translation>
    </message>
    <message>
        <source>(no stemming)</source>
        <translation>(без словоформ)</translation>
    </message>
    <message>
        <source>(all languages)</source>
        <translation>(все языки)</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>ошибка получения списка языков</translation>
    </message>
    <message>
        <source>Update &amp;Index</source>
        <translation>Обновить &amp;индекс</translation>
    </message>
    <message>
        <source>Indexing interrupted</source>
        <translation>Индексирование прервано</translation>
    </message>
    <message>
        <source>Stop &amp;Indexing</source>
        <translation>П&amp;рервать индексирование</translation>
    </message>
    <message>
        <source>Can&apos;t start query: </source>
        <translation>Ошибка старта запроса:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>все</translation>
    </message>
    <message>
        <source>media</source>
        <translation>медиа</translation>
    </message>
    <message>
        <source>message</source>
        <translation>сообщения</translation>
    </message>
    <message>
        <source>other</source>
        <translation>иное</translation>
    </message>
    <message>
        <source>presentation</source>
        <translation>презентации</translation>
    </message>
    <message>
        <source>spreadsheet</source>
        <translation>таблицы</translation>
    </message>
    <message>
        <source>text</source>
        <translation>текст</translation>
    </message>
    <message>
        <source>sorted</source>
        <translation>сортированное</translation>
    </message>
    <message>
        <source>filtered</source>
        <translation>фильтрованное</translation>
    </message>
    <message>
        <source>External applications/commands needed and not found for indexing your file types:

</source>
        <translation>Отсутствующие внешние приложения/команды, требуемые для индексирования ваших файлов:

</translation>
    </message>
    <message>
        <source>No helpers found missing</source>
        <translation>Все вспомогательные программы доступны</translation>
    </message>
    <message>
        <source>Missing helper programs</source>
        <translation>Недостающие вспомогательные программы</translation>
    </message>
    <message>
        <source>Save file dialog</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <source>Choose a file name to save under</source>
        <translation>Выберите имя файла для сохранения</translation>
    </message>
    <message>
        <source>Document category filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No external viewer configured for mime type [</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The viewer specified in mimeview for %1: %2 is not found.
Do you want to start the  preferences dialog ?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RclMainBase</name>
    <message>
        <source>Recoll</source>
        <translation>Recoll</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Инструменты</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Подсказка</translation>
    </message>
    <message>
        <source>Search tools</source>
        <translation>Инструменты поиска</translation>
    </message>
    <message>
        <source>Result list</source>
        <translation>Список результатов</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Выход</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>Start Indexing</source>
        <translation type="obsolete">Индексировать</translation>
    </message>
    <message>
        <source>Start &amp;Indexing</source>
        <translation type="obsolete">&amp;Начать индексирование</translation>
    </message>
    <message>
        <source>About Recoll</source>
        <translation type="obsolete">О программе</translation>
    </message>
    <message>
        <source>&amp;About Recoll</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <source>User manual</source>
        <translation type="obsolete">Руководство</translation>
    </message>
    <message>
        <source>&amp;User manual</source>
        <translation>&amp;Руководство</translation>
    </message>
    <message>
        <source>Document &amp;History</source>
        <translation>&amp;История документов</translation>
    </message>
    <message>
        <source>Document  History</source>
        <translation>История документов</translation>
    </message>
    <message>
        <source>Advanced Search</source>
        <translation type="obsolete">Сложный поиск</translation>
    </message>
    <message>
        <source>&amp;Advanced Search</source>
        <translation>&amp;Сложный поиск</translation>
    </message>
    <message>
        <source>Advanced/complex  Search</source>
        <translation>Сложный поиск</translation>
    </message>
    <message>
        <source>&amp;Sort parameters</source>
        <translation>&amp;Параметры сортировки</translation>
    </message>
    <message>
        <source>Sort parameters</source>
        <translation>Параметры сортировки</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation>След. страница</translation>
    </message>
    <message>
        <source>Next page of results</source>
        <translation>Следующая страница результатов</translation>
    </message>
    <message>
        <source>Previous page</source>
        <translation>Пред. страница</translation>
    </message>
    <message>
        <source>Previous page of results</source>
        <translation>Предыдущая страница результатов</translation>
    </message>
    <message>
        <source>&amp;Query configuration</source>
        <translation>&amp;Конфигурация</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Update index</source>
        <translation type="obsolete">Обновить индекс</translation>
    </message>
    <message>
        <source>Update &amp;index</source>
        <translation>Обновить &amp;индекс</translation>
    </message>
    <message>
        <source>Term &amp;explorer</source>
        <translation>Навигатор &amp;терминов</translation>
    </message>
    <message>
        <source>Term explorer tool</source>
        <translation>Инструмент исследования терминов</translation>
    </message>
    <message>
        <source>External index dialog</source>
        <translation>Диалог внешнего индекса</translation>
    </message>
    <message>
        <source>&amp;Erase document history</source>
        <translation>&amp;Очистить историю документов</translation>
    </message>
    <message>
        <source>First page</source>
        <translation>Первая страница</translation>
    </message>
    <message>
        <source>Go to first page of results</source>
        <translation>Перейти к первой странице результатов</translation>
    </message>
    <message>
        <source>&amp;Indexing configuration</source>
        <translation>Настройки ин&amp;дексирования</translation>
    </message>
    <message>
        <source>All</source>
        <translation>все</translation>
    </message>
    <message>
        <source>&amp;Show missing helpers</source>
        <translation>Недостающие внешние программы</translation>
    </message>
</context>
<context>
    <name>RclResList</name>
    <message>
        <source>Result list</source>
        <translation type="obsolete">Список результатов</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="obsolete">Документ недоступен</translation>
    </message>
    <message>
        <source>Show query details</source>
        <translation type="obsolete">Показать запрос</translation>
    </message>
    <message>
        <source>&lt;b&gt;Displaying results starting at index %1 (maximum set size %2)&lt;/b&gt;&lt;/p&gt;
</source>
        <translation type="obsolete">&lt;b&gt;Результаты, начиная с %1 (всего %2)&lt;/b&gt;&lt;/p&gt;
</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">&amp;Просмотр</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="obsolete">&amp;Редактирование</translation>
    </message>
    <message>
        <source>&amp;Copy File Name</source>
        <translation type="obsolete">&amp;Копировать имя файла</translation>
    </message>
    <message>
        <source>Copy &amp;Url</source>
        <translation type="obsolete">Копировать &amp;адрес</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;Не найдено&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&amp;More like this</source>
        <translation type="obsolete">&amp;Другие похожие</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation type="obsolete">Детали запроса</translation>
    </message>
</context>
<context>
    <name>RecollMain</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Искать</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Очистить</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="obsolete">Ctrl+S</translation>
    </message>
    <message>
        <source>Previous page</source>
        <translation type="obsolete">Пред. страница</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation type="obsolete">След. страница</translation>
    </message>
    <message>
        <source>Advanced search</source>
        <translation type="obsolete">Сложный поиск</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="obsolete">&amp;Файл</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Выход</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="obsolete">&amp;Выход</translation>
    </message>
    <message>
        <source>Start Indexing</source>
        <translation type="obsolete">Начать индексирование</translation>
    </message>
    <message>
        <source>About Recoll</source>
        <translation type="obsolete">О программе</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation type="obsolete">&amp;Инструменты</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="obsolete">&amp;Подсказка</translation>
    </message>
    <message>
        <source>Doc History</source>
        <translation type="obsolete">История документов</translation>
    </message>
    <message>
        <source>Indexing in progress</source>
        <translation type="obsolete">Идёт индексирование</translation>
    </message>
    <message>
        <source>No external viewer configured for mime type </source>
        <translation type="obsolete">Неизвестна программа просмотра для </translation>
    </message>
    <message>
        <source>Executing: [</source>
        <translation type="obsolete">Выполняю: [</translation>
    </message>
    <message>
        <source>Cannot retrieve document info from database</source>
        <translation type="obsolete">Невозможно извлечь документ из БД</translation>
    </message>
    <message>
        <source>Cannot access document file: </source>
        <translation type="obsolete">Невозможно открыть документ: </translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Предв. просмотр</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="obsolete">Осторожно</translation>
    </message>
    <message>
        <source>Can&apos;t create preview window</source>
        <translation type="obsolete">Невозможно создать окно предв. просмотра</translation>
    </message>
    <message>
        <source>Recoll</source>
        <translation type="obsolete">Recoll</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation type="obsolete">Панель инструментов</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="obsolete">Инструменты</translation>
    </message>
    <message>
        <source>Start &amp;Indexing</source>
        <translation type="obsolete">&amp;Начать индексирование</translation>
    </message>
    <message>
        <source>&amp;About Recoll</source>
        <translation type="obsolete">&amp;О программе</translation>
    </message>
    <message>
        <source>Doc &amp;History</source>
        <translation type="obsolete">&amp;История документов</translation>
    </message>
    <message>
        <source>Advanced Search</source>
        <translation type="obsolete">&amp;Сложный поиск</translation>
    </message>
    <message>
        <source>Sort parameters</source>
        <translation type="obsolete">&amp;Параметры сортировки</translation>
    </message>
    <message>
        <source>&lt;b&gt;Displaying results starting at index %1 (maximum set size %2)&lt;/b&gt;&lt;/p&gt;
<byte value="x9"/></source>
        <translation type="obsolete">&lt;b&gt;Результаты с %1 из %2&lt;/b&gt;&lt;/p&gt;&lt;/b&gt;&lt;/p&gt;
<byte value="x9"/></translation>
    </message>
    <message>
        <source>Sort criteria</source>
        <translation type="obsolete">Критерии сортировки</translation>
    </message>
</context>
<context>
    <name>ResList</name>
    <message>
        <source>Result list</source>
        <translation>Список результатов</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation>Документ недоступен</translation>
    </message>
    <message>
        <source>Show query details</source>
        <translation type="obsolete">Показать запрос</translation>
    </message>
    <message>
        <source>&lt;b&gt;Displaying results starting at index %1 (maximum set size %2)&lt;/b&gt;&lt;/p&gt;
</source>
        <translation type="obsolete">&lt;b&gt;Отображены результаты, начиная с %1 (не более %2)&lt;/b&gt;&lt;p&gt;
</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Предыдущая</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следующая</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Не найдено&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Просмотр</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Редактирование</translation>
    </message>
    <message>
        <source>&amp;Copy File Name</source>
        <translation type="obsolete">&amp;Копировать имя файла</translation>
    </message>
    <message>
        <source>Copy &amp;Url</source>
        <translation type="obsolete">Копировать &amp;адрес</translation>
    </message>
    <message>
        <source>Find &amp;similar documents</source>
        <translation>Найти &amp;подобные документы</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation>Подробности запроса</translation>
    </message>
    <message>
        <source>(show query)</source>
        <translation>(показать запрос)</translation>
    </message>
    <message>
        <source>Copy &amp;File Name</source>
        <translation>Скопировать &amp;имя файла</translation>
    </message>
    <message>
        <source>P&amp;arent document/folder</source>
        <translation type="obsolete">&amp;Родительский документ/каталог</translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; out of at least &lt;b&gt;%3&lt;/b&gt; for </source>
        <translation type="obsolete">Документы &lt;b&gt;%1-%2&lt;/b&gt; из минимум &lt;b&gt;%3&lt;/b&gt; по </translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; for </source>
        <translation type="obsolete">Документы &lt;b&gt;%1-%2&lt;/b&gt; по</translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation>Копировать &amp;URL</translation>
    </message>
    <message>
        <source>filtered</source>
        <translation>фильтрованное</translation>
    </message>
    <message>
        <source>sorted</source>
        <translation>сортированное</translation>
    </message>
    <message>
        <source>Document history</source>
        <translation>История документов</translation>
    </message>
    <message>
        <source>Save to File</source>
        <translation type="obsolete">Сохранить в файл</translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; out of at least &lt;b&gt;%d&lt;/b&gt; for </source>
        <translation>Документы &lt;b&gt;%d-%d&lt;/b&gt; из минимум &lt;b&gt;%d&lt;/b&gt; для</translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; for </source>
        <translation>Документы &lt;b&gt;%d-%d&lt;/b&gt; для</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Предпросмотр</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;i&gt;Alternate spellings (accents suppressed): &lt;/i&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Write to File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preview P&amp;arent document/folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open Parent document/folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResListBase</name>
    <message>
        <source>Result list</source>
        <translation type="obsolete">Список результатов</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="obsolete">Документ недоступен</translation>
    </message>
    <message>
        <source>&lt;b&gt;Displaying results starting at index %1 (maximum set size %2)&lt;/b&gt;&lt;/p&gt;
</source>
        <translation type="obsolete">&lt;b&gt;Отображаю результаты начиная с %1 (не более %2)&lt;/b&gt;&lt;/p&gt;
</translation>
    </message>
</context>
<context>
    <name>SSearch</name>
    <message>
        <source>Any term</source>
        <translation>Любое слово</translation>
    </message>
    <message>
        <source>All terms</source>
        <translation>Все слова</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <source>Completions</source>
        <translation>Дополнения</translation>
    </message>
    <message>
        <source>Select an item:</source>
        <translation>Выберите:</translation>
    </message>
    <message>
        <source>Too many completions</source>
        <translation>Слишком много дополнений</translation>
    </message>
    <message>
        <source>Query language</source>
        <translation>Язык запроса</translation>
    </message>
    <message>
        <source>Bad query string</source>
        <translation>Неверная строка запроса</translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation>Недостаточно памяти</translation>
    </message>
</context>
<context>
    <name>SSearchBase</name>
    <message>
        <source>SSearchBase</source>
        <translation></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Erase search entry</source>
        <translation>Очистить поле ввода</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Искать</translation>
    </message>
    <message>
        <source>Start query</source>
        <translation>Приступить к поиску</translation>
    </message>
    <message>
        <source>&amp;All terms</source>
        <translation type="obsolete">&amp;Все слова</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation type="obsolete">Alt-A</translation>
    </message>
    <message>
        <source>Do documents have to contain all terms in query?</source>
        <translation type="obsolete">Должны ли документы содержать все слова запроса?</translation>
    </message>
    <message>
        <source>If this is set, each returned document will contain all the terms in the query. Else documents will be ordered by relevance, but may not contain all the terms.</source>
        <translation type="obsolete">Если включено, каждый найденный документ содержит все слова запроса.  Иначе документы сортируются по релевантности, но могут содержать не все слова.</translation>
    </message>
    <message>
        <source>Enter search terms here</source>
        <translation type="obsolete">Введите ключевые слова</translation>
    </message>
    <message>
        <source>Choose type of search: any term, all terms, filename with possible wildcards.</source>
        <translation type="obsolete">Выберите тип поиска: любое слово, все слова, имя файла (шаблоны работают).</translation>
    </message>
    <message>
        <source>Any term</source>
        <translation type="obsolete">Любое слово</translation>
    </message>
    <message>
        <source>All terms</source>
        <translation type="obsolete">Все слова</translation>
    </message>
    <message>
        <source>File name</source>
        <translation type="obsolete">Имя файла</translation>
    </message>
    <message>
        <source>Completions</source>
        <translation type="obsolete">Дополнения</translation>
    </message>
    <message>
        <source>Select an item:</source>
        <translation type="obsolete">Выберите:</translation>
    </message>
    <message>
        <source>Enter search terms here. CTRL-TAB for completions of current term.</source>
        <translation type="obsolete">Введите слова для поиска.  Ctrl-Tab для дополнения текущего.</translation>
    </message>
    <message>
        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
        <translation>Введите поисковые слова.  Можно нажать Esc-пробел для дополнения текущего слова.</translation>
    </message>
    <message>
        <source>Choose search type.</source>
        <translation>Выберите тип поиска</translation>
    </message>
</context>
<context>
    <name>SearchClauseW</name>
    <message>
        <source>SearchClauseW</source>
        <translation></translation>
    </message>
    <message>
        <source>Any of these</source>
        <translation>с любыми словами</translation>
    </message>
    <message>
        <source>All of these</source>
        <translation>со всеми словами</translation>
    </message>
    <message>
        <source>None of these</source>
        <translation>без этих слов</translation>
    </message>
    <message>
        <source>This phrase</source>
        <translation>фраза</translation>
    </message>
    <message>
        <source>Terms in proximity</source>
        <translation>слова вблизи</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation>имя файла</translation>
    </message>
    <message>
        <source>Select the type of query that will be performed with the words</source>
        <translation>Выберите тип запроса, который будет произведён по словам</translation>
    </message>
    <message>
        <source>Number of additional words that may be interspersed with the chosen ones</source>
        <translation>Количество дополнительных слов, которые могут оказаться между выбранными</translation>
    </message>
</context>
<context>
    <name>SortForm</name>
    <message>
        <source>Sort Criteria</source>
        <translation type="obsolete">Критерии сортировки</translation>
    </message>
    <message>
        <source>Sort the</source>
        <translation type="obsolete">Сортировать</translation>
    </message>
    <message>
        <source>most relevant results by:</source>
        <translation type="obsolete">наиболее похожих результатов по:</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="obsolete">убыванию</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Вернуть</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Закрыть</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation>Тип MIME</translation>
    </message>
</context>
<context>
    <name>SortFormBase</name>
    <message>
        <source>Sort Criteria</source>
        <translation>Критерии сортировки</translation>
    </message>
    <message>
        <source>Sort the</source>
        <translation>Сортировать</translation>
    </message>
    <message>
        <source>most relevant results by:</source>
        <translation>наиболее похожих результатов по:</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation>убыванию</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Вернуть</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
</context>
<context>
    <name>SpellBase</name>
    <message>
        <source>Term Explorer</source>
        <translation>Навигатор терминов</translation>
    </message>
    <message>
        <source>&amp;Expand </source>
        <translation>&amp;Раскрыть </translation>
    </message>
    <message>
        <source>Alt+E</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <source>Term</source>
        <translation>Слово</translation>
    </message>
    <message>
        <source>Count</source>
        <translation>Количество</translation>
    </message>
</context>
<context>
    <name>SpellW</name>
    <message>
        <source>Wildcards</source>
        <translation>Шаблоны</translation>
    </message>
    <message>
        <source>Regexp</source>
        <translation>Регвыражение</translation>
    </message>
    <message>
        <source>Spelling/Phonetic</source>
        <translation>Написание/фонетика</translation>
    </message>
    <message>
        <source>Aspell init failed. Aspell not installed?</source>
        <translation>Не получилось инициализировать Aspell.  Он установлен?</translation>
    </message>
    <message>
        <source>Aspell expansion error. </source>
        <translation>Ошибка раскрывания aspell. </translation>
    </message>
    <message>
        <source>Stem expansion</source>
        <translation>Раскрытие основы</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>ошибка получения списка языков</translation>
    </message>
    <message>
        <source>No expansion found</source>
        <translation>Раскрытие не найдено</translation>
    </message>
</context>
<context>
    <name>UIPrefsDialog</name>
    <message>
        <source>User interface</source>
        <translation type="obsolete">Интерфейс</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation type="obsolete">Количество записей на страницу результатов</translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation type="obsolete">Шрифт списка результатов</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation type="obsolete">Helvetica-10</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation type="obsolete">Открывает диалог выбора шрифта списка результатов</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Вернуть</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation type="obsolete">Устанавливает шрифт списка результатов в обычный</translation>
    </message>
    <message>
        <source>HTML help browser</source>
        <translation type="obsolete">Просмотр справки в HTML</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation type="obsolete">Выберите файл</translation>
    </message>
    <message>
        <source>Show document type icons in result list</source>
        <translation type="obsolete">Показывать пиктограммы типов документов</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation type="obsolete">Поиск</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation type="obsolete">Язык словообразования</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation type="obsolete">Динамическое выделение контекста</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation type="obsolete">Следует ли пытаться построить сжатые фрагменты из найденных документов, опираясь на контекст ключевых слов?
Может быть медленным для больших документов.</translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation type="obsolete">Замещать контекст документов</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation type="obsolete">Создавать ли сжатое изложение, если документ уже имеет его?</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation type="obsolete">Применить изменения</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Отмена</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation type="obsolete">Отменить изменения</translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry</source>
        <translation type="obsolete">Автостарт простого запроса при вводе с пробелами</translation>
    </message>
    <message>
        <source>Extra Databases</source>
        <translation type="obsolete">Дополнительные базы</translation>
    </message>
    <message>
        <source>Add database</source>
        <translation type="obsolete">Добавить</translation>
    </message>
    <message>
        <source>Select the xapiandb directory for the  database you want to add, then click Add Database</source>
        <translation type="obsolete">Выберите каталог xapiandb для БД, которую хотите добавить, и нажмите &quot;Добавить&quot;</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="obsolete">Просмотр</translation>
    </message>
    <message>
        <source>All extra databases</source>
        <translation type="obsolete">Все</translation>
    </message>
    <message>
        <source>All known extra databases</source>
        <translation type="obsolete">Все известные дополнительные базы данных</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation type="obsolete">Все ----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation type="obsolete">Эти ----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation type="obsolete">&lt;----- Эти</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation type="obsolete">&lt;----- Все</translation>
    </message>
    <message>
        <source>Active extra databases</source>
        <translation type="obsolete">Активные</translation>
    </message>
    <message>
        <source>Extra databases that will be searched in addition to the main one</source>
        <translation type="obsolete">Дополнительные базы данных, по которым производится поиск, помимо основной</translation>
    </message>
    <message>
        <source>The selected directory does not appear to be a Xapian database</source>
        <translation type="obsolete">Выбранный каталог не похож на БД Xapian</translation>
    </message>
    <message>
        <source>This is the main/local database!</source>
        <translation type="obsolete">Это основная/локальная база!</translation>
    </message>
    <message>
        <source>The selected directory is already in the database list</source>
        <translation type="obsolete">Выбранный каталог уже в списке</translation>
    </message>
    <message>
        <source>Select directory holding xapian database (ie: /home/someone/.recoll/xapiandb)</source>
        <translation type="obsolete">Выберите каталог, содержащий базу xapian (например, /home/someone/.recoll/xapiandb)</translation>
    </message>
    <message>
        <source>(no stemming)</source>
        <translation type="obsolete">(без словоформ)</translation>
    </message>
    <message>
        <source>The selected directory does not appear to be a Xapian index</source>
        <translation>Выбранный каталог не похож на индекс Xapian</translation>
    </message>
    <message>
        <source>This is the main/local index!</source>
        <translation>Это главный индекс!</translation>
    </message>
    <message>
        <source>The selected directory is already in the index list</source>
        <translation>Этот каталог уже в списке индексов</translation>
    </message>
    <message>
        <source>Select xapian index directory (ie: /home/buddy/.recoll/xapiandb)</source>
        <translation>Выберите каталог индекса Xapian (например, /home/приятель/.recoll/xapiandb)</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>ошибка получения списка языков</translation>
    </message>
</context>
<context>
    <name>UIPrefsDialogBase</name>
    <message>
        <source>MyDialog</source>
        <translation type="obsolete">MyDialog</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation>Интерфейс</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation>Количество записей на страницу результатов</translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation>Шрифт списка результатов</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation>Helvetica-10</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation>Открывает диалог выбора шрифта списка результатов</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Вернуть</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation>Устанавливает шрифт списка результатов в обычный</translation>
    </message>
    <message>
        <source>HTML help browser</source>
        <translation type="obsolete">Просмотр справки в HTML</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation type="obsolete">Выберите файл</translation>
    </message>
    <message>
        <source>Show document type icons in result list.</source>
        <translation type="obsolete">Отображать типы документов в списке результатов.</translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry.</source>
        <translation>Начинать простой поиск по вводу пробела.</translation>
    </message>
    <message>
        <source>Start with advanced search dialog open.</source>
        <translation>Открывать диалог сложного поиска при запуске.</translation>
    </message>
    <message>
        <source>Start with sort dialog open.</source>
        <translation>Открывать диалог сортировки при запуске.</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation>Параметры поиска</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation>Язык словоформ</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searchs</source>
        <translation type="obsolete">Автоматически добавлять фразу к простому поиску</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)].</source>
        <translation type="obsolete">Поиск [rolling stones] (2 terms) будет заменён на [rolling or stones or (rolling phrase 2 stones)].</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation>Динамическое выделение конспекта</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation>Следует ли пытаться построить конспект из найденных документов, опираясь на контекст ключевых слов?
Может быть медленным для больших документов.</translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation>Замещать конспект, содержащийся в документах</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation>Создавать ли конспект, если документ уже имеет его?</translation>
    </message>
    <message>
        <source>Synthetic abstract size (characters)</source>
        <translation>Размер создаваемого конспекта (в символах)</translation>
    </message>
    <message>
        <source>Synthetic abstract context words</source>
        <translation>Контекстных слов</translation>
    </message>
    <message>
        <source>External Indexes</source>
        <translation>Внешние индексы</translation>
    </message>
    <message>
        <source>Add index</source>
        <translation>Добавить индекс</translation>
    </message>
    <message>
        <source>Select the xapiandb directory for the index you want to add, then click Add Index</source>
        <translation>Выберите нужный каталог с индексом Xapian и нажмите &quot;Добавить индекс&quot;</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>All indexes</source>
        <translation type="obsolete">Все индексы</translation>
    </message>
    <message>
        <source>Indexes currently not used</source>
        <translation type="obsolete">Неиспользуемые</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation type="obsolete">Все ----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation type="obsolete">Эти ----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation type="obsolete">&lt;----- Эти</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation type="obsolete">&lt;----- Все</translation>
    </message>
    <message>
        <source>Active indexes</source>
        <translation type="obsolete">Активные</translation>
    </message>
    <message>
        <source>Indexes that will be searched in addition to the main one</source>
        <translation type="obsolete">Индексы, которые будут использоваться для поиска в дополнение к основному</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation>Применить изменения</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation>Отменить изменения</translation>
    </message>
    <message>
        <source>Result paragraph&lt;br&gt;format string</source>
        <translation>Строка форматирования&lt;br&gt;блока результатов</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searches</source>
        <translation>Автоматически добавлять фразу при простом поиске</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
This should give higher precedence to the results where the search terms appear exactly as entered.</source>
        <translation>Поиск [rolling stones] (два слова) будет изменён на [rolling или stones или (rolling phrase 2 stones)].
Это может поднять результаты, для которых слова следуют именно в том порядке, как введены.</translation>
    </message>
    <message>
        <source>Choose external viewer applications</source>
        <translation type="obsolete">Выбрать внешние приложения просмотра</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="obsolete">Упорядочить</translation>
    </message>
    <message>
        <source>User preferences</source>
        <translation>Предпочтения</translation>
    </message>
    <message>
        <source>Use desktop preferences to choose document editor.</source>
        <translation>Использовать десктопные настройки для выбора редактора документов.</translation>
    </message>
    <message>
        <source>External indexes</source>
        <translation>Внешние индексы</translation>
    </message>
    <message>
        <source>Toggle selected</source>
        <translation>Переключить выделенные</translation>
    </message>
    <message>
        <source>Activate All</source>
        <translation>Включить все</translation>
    </message>
    <message>
        <source>Desactivate All</source>
        <translation type="obsolete">Выключить все</translation>
    </message>
    <message>
        <source>Remove selected</source>
        <translation>Удалить выделенные</translation>
    </message>
    <message>
        <source>Remove from list. This has no effect on the disk index.</source>
        <translation>Удалить из списка. Индекс на диске без изменений.</translation>
    </message>
    <message>
        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
        <translation>Определяет формат каждого блока списка результатов. Используйте html-формат qt и замены в стиле printf:&lt;br&gt;%A аннотация&lt;br&gt; %D дата&lt;br&gt; %I название пиктограммы&lt;br&gt; %K ключевые слова (если есть)&lt;br&gt; %L ссылки предварительного просмотра и редактирования&lt;br&gt; %M тип MIME&lt;br&gt; %N количество результатов&lt;br&gt; %R релевантность&lt;br&gt; %S размер&lt;br&gt; %T заголовок&lt;br&gt; %U URL&lt;br&gt;</translation>
    </message>
    <message>
        <source>Remember sort activation state.</source>
        <translation>Запомнить состояние сортировки.</translation>
    </message>
    <message>
        <source>Maximum text size highlighted for preview (megabytes)</source>
        <translation>Максимальный объём текста с выделением при просмотре (Мб)</translation>
    </message>
    <message>
        <source>Texts over this size will not be highlighted in preview (too slow).</source>
        <translation>Тексты большего размера не будут подсвечиваться при предварительном просмотре (медленно).</translation>
    </message>
    <message>
        <source>Highlight color for query terms</source>
        <translation>Цвет выделения ключевых слов</translation>
    </message>
    <message>
        <source>Deactivate All</source>
        <translation>Выключить все</translation>
    </message>
    <message>
        <source>Prefer Html to plain text for preview.</source>
        <translation>Предпочитать HTML тексту для предпросмотра</translation>
    </message>
    <message>
        <source>If checked, results with the same content under different names will only be shown once.</source>
        <translation>Показывать результаты с тем же содержанием под разными именами не более одного раза</translation>
    </message>
    <message>
        <source>Hide duplicate results.</source>
        <translation>Прятать дубликаты</translation>
    </message>
    <message>
        <source>Choose editor applications</source>
        <translation>Выбор редакторов</translation>
    </message>
    <message>
        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewAction</name>
    <message>
        <source>Changing actions with different current values</source>
        <translation>Изменение действий с различными текущими значениями</translation>
    </message>
</context>
<context>
    <name>ViewActionBase</name>
    <message>
        <source>File type</source>
        <translation>Тип файла</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <source>Select one or several file types, then click Change Action to modify the program used to open them</source>
        <translation>Выберите один или несколько типов файлов, затем нажмите &quot;Сменить действие&quot; для изменения программы, работающей с ними</translation>
    </message>
    <message>
        <source>Change Action</source>
        <translation>Сменить действие</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Native Viewers</source>
        <translation>Родные вьюеры</translation>
    </message>
    <message>
        <source>Select one or several mime types then click &quot;Change Action&quot;</source>
        <translation type="obsolete">Выберите один или несколько MIME-типов и нажмите &quot;Сменить действие&quot;</translation>
    </message>
    <message>
        <source>Select one or several mime types then click &quot;Change Action&quot;&lt;br&gt;You can also close this dialog and check &quot;Use desktop preferences&quot;&lt;br&gt;in the main panel to ignore this list and use your desktop defaults.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>advsearch</name>
    <message>
        <source>Advanced search</source>
        <translation type="obsolete">Сложный поиск</translation>
    </message>
    <message>
        <source>Search For</source>
        <translation type="obsolete">Искать</translation>
    </message>
    <message>
        <source>All these words</source>
        <translation type="obsolete">Все слова</translation>
    </message>
    <message>
        <source>This exact phrase</source>
        <translation type="obsolete">Точную фразу</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation type="obsolete">Любое из слов</translation>
    </message>
    <message>
        <source>None of these words</source>
        <translation type="obsolete">Ни одно из слов</translation>
    </message>
    <message>
        <source>Restrict file types</source>
        <translation type="obsolete">Ограничить типы файлов</translation>
    </message>
    <message>
        <source>Searched file types</source>
        <translation type="obsolete">Искать</translation>
    </message>
    <message>
        <source>Ignored file types</source>
        <translation type="obsolete">Игнорировать</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="obsolete">Просмотр</translation>
    </message>
    <message>
        <source>Restrict results to files in subtree:</source>
        <translation type="obsolete">Ограничиться каталогом:</translation>
    </message>
    <message>
        <source>Start Search</source>
        <translation type="obsolete">Начать поиск</translation>
    </message>
    <message>
        <source>Dismiss</source>
        <translation type="obsolete">Отменить</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation type="obsolete">Все ----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation type="obsolete">Эти ----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation type="obsolete">&lt;----- Эти</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation type="obsolete">&lt;----- Все</translation>
    </message>
    <message>
        <source>Search for files&lt;br&gt;having all of:</source>
        <translation type="obsolete">Искать файлы&lt;br&gt;со всем из:</translation>
    </message>
    <message>
        <source>All non blank fields will be combined with AND conjunctions</source>
        <translation type="obsolete">Все непустые поля будут объединены AND</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation type="obsolete">Поиск по именам файлов</translation>
    </message>
    <message>
        <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
        <translation type="obsolete">Невозможно выполнить полностью негативный запрос. Пожалуйста, введите общие термины в поле &quot;любые слова&quot;</translation>
    </message>
</context>
<context>
    <name>confgui::ConfBeaglePanelW</name>
    <message>
        <source>Steal Beagle indexing queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beagle MUST NOT be running. Enables processing the beagle queue to index Firefox web history.&lt;br&gt;(you should also install the Firefox Beagle plugin)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web cache directory name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name for a directory where to store the cache for visited web pages.&lt;br&gt;A non-absolute path is taken relative to the configuration directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. size for the web cache (MB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Entries will be recycled once the size is reached</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfIndexW</name>
    <message>
        <source>Can&apos;t write configuration file</source>
        <translation>Невозможно записать файл конфигурации</translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamFNW</name>
    <message>
        <source>Browse</source>
        <translation>Просмотр</translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamSLW</name>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
</context>
<context>
    <name>confgui::ConfSubPanelW</name>
    <message>
        <source>Global</source>
        <translation></translation>
    </message>
    <message>
        <source>Max. compressed file size (KB)</source>
        <translation>Предел размера сжатого файла (KB)</translation>
    </message>
    <message>
        <source>This value sets a threshold beyond which compressedfiles will not be processed. Set to -1 for no limit, to 0 for no decompression ever.</source>
        <translation>Это значение устанавливает порог размера сжатых файлов, которые будут обрабатываться. -1 отключает порог, 0 отключает декомпрессию.</translation>
    </message>
    <message>
        <source>Max. text file size (MB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This value sets a threshold beyond which text files will not be processed. Set to -1 for no limit. 
This is for excluding monster log files from the index.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text file page size (KB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this value is set (not equal to -1), text files will be split in chunks of this size for indexing.
This will help searching very big text  files (ie: log files).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. filter exec. time (S)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External filters working longer than this will be aborted. This is for the rare case (ie: postscript) where a document could cause a filter to loopSet to -1 for no limit.
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfTopPanelW</name>
    <message>
        <source>Top directories</source>
        <translation></translation>
    </message>
    <message>
        <source>The list of directories where recursive indexing starts. Default: your home.</source>
        <translation>Список каталогов, где начинается рекурсивное индексирование.  Обычно домашний каталог.</translation>
    </message>
    <message>
        <source>Skipped paths</source>
        <translation>Пропускать</translation>
    </message>
    <message>
        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/tmp*&apos;, not &apos;/usr/home/tmp*&apos;)</source>
        <translation type="obsolete">Имена каталогов, которые индексирование обойдёт.&lt;br&gt;Может содержать шаблоны.  Обязано подходить к путям, которые видит индексатор (например, если topdirs включает &apos;/home/me&apos; и &apos;/home&apos; является ссылкой на &apos;/usr/home&apos;, то правильная запись должна быть &apos;/home/me/tmp*&apos;, а не &apos;/usr/home/me/tmp*&apos;)</translation>
    </message>
    <message>
        <source>Stemming languages</source>
        <translation>Языки со словоформами</translation>
    </message>
    <message>
        <source>The languages for which stemming expansion&lt;br&gt;dictionaries will be built.</source>
        <translation>Языки, для которых будут построены&lt;br&gt;словари раскрытия словоформ.</translation>
    </message>
    <message>
        <source>Log file name</source>
        <translation>Файл журнала</translation>
    </message>
    <message>
        <source>The file where the messages will be written.&lt;br&gt;Use &apos;stderr&apos; for terminal output</source>
        <translation>Файл, куда будут записываться сообщения.&lt;br&gt;&apos;stderr&apos; для вывода на терминал</translation>
    </message>
    <message>
        <source>Log verbosity level</source>
        <translation>Подробность журнала</translation>
    </message>
    <message>
        <source>This value adjusts the amount of messages,&lt;br&gt;from only errors to a lot of debugging data.</source>
        <translation>Это значение определяет подробность сообщений,&lt;br&gt;от ошибок до отладочных данных.</translation>
    </message>
    <message>
        <source>Index flush megabytes interval</source>
        <translation>Интервал записи индекса (Мб)</translation>
    </message>
    <message>
        <source>This value adjust the amount of data which is indexed betweeen flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
        <translation type="obsolete">Это значение определяет количество проиндексированных данных между сбросами на диск.&lt;br&gt;Помогает контролировать использование памяти при индексации.  Обычно 10Mb </translation>
    </message>
    <message>
        <source>Max disk occupation (%)</source>
        <translation>Максимальное использование диска (%)</translation>
    </message>
    <message>
        <source>This is the percentage of disk occupation where indexing will fail and stop (to avoid filling up your disk).&lt;br&gt;0 means no limit (this is the default).</source>
        <translation>Процент занятости диска, при котором индексирование будет прервано (во избежание заполнения доступного места).&lt;br&gt;Обычно: 0 (отключает проверку).</translation>
    </message>
    <message>
        <source>No aspell usage</source>
        <translation>Не использовать aspell</translation>
    </message>
    <message>
        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful is aspell is absent or does not work. </source>
        <translation type="obsolete">Отключает использование aspell для генерации приближений написания в навигаторе терминов.&lt;br&gt; Полезно, если aspell отсутствует или сломан. </translation>
    </message>
    <message>
        <source>Aspell language</source>
        <translation>Язык aspell</translation>
    </message>
    <message>
        <source>The language for the aspell dictionary. This should look like &apos;en&apos; or &apos;fr&apos; ...&lt;br&gt;If this value is not set, the NLS environment will be used to compute it, which usually works.To get an idea of what is installed on your system, type &apos;aspell config&apos; and look for .dat files inside the &apos;data-dir&apos; directory. </source>
        <translation>Язык словаря aspell.  Обычно вроде &apos;en&apos; или &apos;ru&apos;...&lt;br&gt;Если значение не указано, будет использовано окружение (локаль), что обычно работает.  Чтобы посмотреть, какие варианты доступны в системе, наберите &apos;aspell config&apos; и проверьте, какие .dat-файлы есть в каталоге &apos;data-dir&apos;. </translation>
    </message>
    <message>
        <source>Database directory name</source>
        <translation>Каталог базы данных</translation>
    </message>
    <message>
        <source>The name for a directory where to store the index&lt;br&gt;A non-absolute path is taken relative to the  configuration directory. The default is &apos;xapiandb&apos;.</source>
        <translation>Имя каталога, в котором хранится индекс&lt;br&gt;Относительный путь берётся от каталога конфигурации.  Обычно &apos;xapiandb&apos;.</translation>
    </message>
    <message>
        <source>Use system&apos;s &apos;file&apos; command</source>
        <translation>Использовать системную &apos;file&apos;</translation>
    </message>
    <message>
        <source>Use the system&apos;s &apos;file&apos; command if internal&lt;br&gt;mime type identification fails.</source>
        <translation>Использовать системную команду &apos;file&apos; &lt;br&gt;при сбое внутреннего определителя типов MIME.</translation>
    </message>
    <message>
        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/me/tmp*&apos;, not &apos;/usr/home/me/tmp*&apos;)</source>
        <translation>Имена каталогов, которые индексирование обойдёт.&lt;br&gt;Может содержать шаблоны.  Обязано подходить к путям, которые видит индексатор (например, если topdirs включает &apos;/home/me&apos; и &apos;/home&apos; является ссылкой на &apos;/usr/home&apos;, то правильная запись должна быть &apos;/home/me/tmp*&apos;, а не &apos;/usr/home/me/tmp*&apos;)</translation>
    </message>
    <message>
        <source>This value adjust the amount of data which is indexed between flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
        <translation>Это значение определяет количество проиндексированных данных между сбросами на диск.&lt;br&gt;Помогает контролировать использование памяти при индексации.  Обычно 10Mb </translation>
    </message>
    <message>
        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful if aspell is absent or does not work. </source>
        <translation>Отключает использование aspell для генерации приближений написания в навигаторе терминов.&lt;br&gt; Полезно, если aspell отсутствует или сломан. </translation>
    </message>
</context>
</TS>
